==> qcad-3.5.1.0_2.txz: usr/local/share/qcad/scripts/Widgets/LibraryBrowser/ts/LibraryBrowser_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>Favorites</name>
    <message>
        <source>Item &apos;%1&apos; has been added to your favorites.</source>
        <translation type="obsolete">Elemento &apos;%1&apos; è stato aggiunto ai tuoi preferiti.</translation>
    </message>
</context>
<context>
    <name>LibraryBrowser</name>
    <message>
        <location filename="../LibraryBrowser.js" line="+69"/>
        <source>audience</source>
        <translation>Pubblico</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>creator</source>
        <translation>Autore</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>dimension</source>
        <translation>Dimensione</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>levelOfDetail</source>
        <translation>Livello di dettaglio</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>license</source>
        <translation>Licenza</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>perspective</source>
        <translation>Prospettiva</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>presentation</source>
        <translation>Presentazione</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>publisher</source>
        <translation>Editore</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>subject</source>
        <translation>Tema</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>title</source>
        <translation>Titolo</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Widgets</source>
        <translation>Widgets</translation>
    </message>
    <message>
        <location line="+0"/>
        <location line="+1105"/>
        <location filename="../LibraryBrowserInit.js" line="+18"/>
        <source>Library Browser</source>
        <translation>Browser librerie</translation>
    </message>
    <message>
        <location line="-1097"/>
        <source>Icon</source>
        <translation>Icona</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>List</source>
        <translation>Lista</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Choose Source Folder</source>
        <translation>Scegli cartella di origine</translation>
    </message>
    <message>
        <location line="+652"/>
        <source>Page %1 of %2</source>
        <translation>Pagina %1 di %2</translation>
    </message>
    <message>
        <location line="+219"/>
        <source>Updating icons...</source>
        <translation>Rigenerare icone...</translation>
    </message>
    <message>
        <location line="+193"/>
        <source>File:</source>
        <translation>File:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Folder:</source>
        <translation>Cartella:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>License:</source>
        <translation>Licenza:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Attribute as:</source>
        <translation>Attribuzione:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Creator:</source>
        <translation>Autore:</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Updating library index:</source>
        <translation>Aggiornamento:</translation>
    </message>
    <message>
        <source>Updating index...</source>
        <translation type="obsolete">Aggiornamento...</translation>
    </message>
    <message>
        <location line="-218"/>
        <location line="+219"/>
        <source>Abort</source>
        <translation>Interrompi</translation>
    </message>
    <message>
        <source>Updating index:</source>
        <translation type="obsolete">Aggiornamento:</translation>
    </message>
    <message>
        <location line="+29"/>
        <source>DB error</source>
        <translation>DB errore</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plugin LibraryBrowser: cannot connect to DB.
Driver error: %1
Database error: %2
Database file: %3
Library browser will not be available.</source>
        <translation>Plugin LibraryBrowser: cannot connect to DB.
Driver error: %1
Database error: %2
Database file: %3
Library browser will not be available.</translation>
    </message>
    <message>
        <location line="+446"/>
        <source>&amp;Insert</source>
        <translation>&amp;Inserisci</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Edit Script File...</source>
        <translation>&amp;Modificare file di script...</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Open &amp;SVG File...</source>
        <translation>Apri file &amp;SVG...</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>&amp;Open...</source>
        <translation>&amp;Apri...</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>&amp;Edit...</source>
        <translation>&amp;Modifica…</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>File Browser</source>
        <translation>File</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>&amp;Show in %1...</source>
        <translation>&amp;Mostrare con %1...</translation>
    </message>
    <message>
        <location line="+28"/>
        <source>&amp;Remove from Favorites</source>
        <translation>&amp;Rimuovi da preferiti</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>&amp;Add to Favorites</source>
        <translation>&amp;Aggiungi ai preferiti</translation>
    </message>
    <message>
        <location line="+34"/>
        <source>&amp;Regenerate Icon</source>
        <translation>Rigenerare &amp;icona</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>&amp;Regenerate Icons</source>
        <translation>&amp;Rigenerare icone</translation>
    </message>
    <message>
        <source>Preferences</source>
        <translation type="obsolete">Preferenze</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Synchronization</source>
        <translation>Sincronizzazione</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Update search index on startup</source>
        <translation>Aggiornamento indice di ricerca all&apos;avvio</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Display Options</source>
        <translation>Opzioni di visualizzazione</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Icon Size:</source>
        <translation>Icona dimensione:</translation>
    </message>
    <message>
        <location line="+44"/>
        <source>View Mode:</source>
        <translation>Modalità di visualizzazione:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Number of items
shown in search results:</source>
        <translation>Numero di oggetti
mostrati nei risultati di ricerca:</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>Library Sources</source>
        <translation>Biblioteca fonti</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Add...</source>
        <translation>Aggiungi…</translation>
    </message>
    <message>
        <source>Add ...</source>
        <translation type="obsolete">Aggiungi…</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Remove</source>
        <translation>Rimuovi</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Up</source>
        <translation>Su</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Down</source>
        <translation>Giù</translation>
    </message>
    <message>
        <location filename="../LibraryBrowserInit.js" line="-10"/>
        <source>&amp;Library Browser</source>
        <translation>&amp;Browser Librerie</translation>
    </message>
</context>
<context>
    <name>LibraryBrowserForm</name>
    <message>
        <location filename="../LibraryBrowser.ui" line="+28"/>
        <source>File System</source>
        <translation>File system</translation>
    </message>
    <message>
        <location line="+252"/>
        <source>Favorites</source>
        <translation>Preferiti</translation>
    </message>
    <message>
        <location line="-201"/>
        <source>Tags</source>
        <translation>Tags</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Look for:</source>
        <translation>Cerca per:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Clear</source>
        <translation>Pulisci</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Find</source>
        <translation>Trova</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>Reset tag selection</source>
        <translation>Reimposta</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>about:blank</source>
        <translation>about:blank</translation>
    </message>
    <message>
        <location line="+157"/>
        <source>Update DB from file system</source>
        <translation>Aggiorna</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>0</source>
        <translation>0</translation>
    </message>
</context>
</TS>

==> qcad-3.15.2.0.txz: usr/local/share/qcad/scripts/Widgets/LibraryBrowser/ts/LibraryBrowser_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>Favorites</name>
    <message>
        <source>Item &apos;%1&apos; has been added to your favorites.</source>
        <translation type="obsolete">Elemento &apos;%1&apos; è stato aggiunto ai tuoi preferiti.</translation>
    </message>
</context>
<context>
    <name>LibraryBrowser</name>
    <message>
        <location filename="../LibraryBrowser.js" line="+71"/>
        <source>audience</source>
        <translation>Pubblico</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>creator</source>
        <translation>Autore</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>dimension</source>
        <translation>Dimensione</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>levelOfDetail</source>
        <translation>Livello di dettaglio</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>license</source>
        <translation>Licenza</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>perspective</source>
        <translation>Prospettiva</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>presentation</source>
        <translation>Presentazione</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>publisher</source>
        <translation>Editore</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>subject</source>
        <translation>Tema</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>title</source>
        <translation>Titolo</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Widgets</source>
        <translation>Widgets</translation>
    </message>
    <message>
        <location line="+0"/>
        <location line="+1153"/>
        <location filename="../LibraryBrowserInit.js" line="+19"/>
        <source>Library Browser</source>
        <translation>Browser librerie</translation>
    </message>
    <message>
        <location line="-1145"/>
        <source>Icon</source>
        <translation>Icona</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>List</source>
        <translation>Lista</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Choose Source Folder</source>
        <translation>Scegli cartella di origine</translation>
    </message>
    <message>
        <location line="+685"/>
        <source>Page %1 of %2</source>
        <translation>Pagina %1 di %2</translation>
    </message>
    <message>
        <location line="+235"/>
        <source>Updating icons...</source>
        <translation>Rigenerare icone...</translation>
    </message>
    <message>
        <location line="+193"/>
        <source>File:</source>
        <translation>File:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Folder:</source>
        <translation>Cartella:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>License:</source>
        <translation>Licenza:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Attribute as:</source>
        <translation>Attribuzione:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Creator:</source>
        <translation>Autore:</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Updating library index:</source>
        <translation>Aggiornamento:</translation>
    </message>
    <message>
        <source>Updating index...</source>
        <translation type="obsolete">Aggiornamento...</translation>
    </message>
    <message>
        <location line="-218"/>
        <location line="+219"/>
        <source>Abort</source>
        <translation>Interrompi</translation>
    </message>
    <message>
        <source>Updating index:</source>
        <translation type="obsolete">Aggiornamento:</translation>
    </message>
    <message>
        <location line="+29"/>
        <source>DB error</source>
        <translation>DB errore</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plugin LibraryBrowser: cannot connect to DB.
Driver error: %1
Database error: %2
Database file: %3
Library browser will not be available.</source>
        <translation>Plugin LibraryBrowser: cannot connect to DB.
Driver error: %1
Database error: %2
Database file: %3
Library browser will not be available.</translation>
    </message>
    <message>
        <location line="+43"/>
        <source>Source removed from part library: %1</source>
        <translation>Fonte rimosso dalla biblioteca: %1</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Force database update.</source>
        <translation>Costretto aggiornamento del database.</translation>
    </message>
    <message>
        <location line="+393"/>
        <source>&amp;Insert</source>
        <translation>&amp;Inserisci</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Edit Script File...</source>
        <translation>&amp;Modificare file di script...</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Open &amp;SVG File...</source>
        <translation>Apri file &amp;SVG...</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>&amp;Open...</source>
        <translation>&amp;Apri...</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>&amp;Edit...</source>
        <translation>&amp;Modifica…</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>File Browser</source>
        <translation>File</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>&amp;Show in %1...</source>
        <translation>&amp;Mostrare con %1...</translation>
    </message>
    <message>
        <location line="+28"/>
        <source>&amp;Remove from Favorites</source>
        <translation>&amp;Rimuovi da preferiti</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>&amp;Add to Favorites</source>
        <translation>&amp;Aggiungi ai preferiti</translation>
    </message>
    <message>
        <location line="+34"/>
        <source>&amp;Regenerate Icon</source>
        <translation>Rigenerare &amp;icona</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>&amp;Regenerate Icons</source>
        <translation>&amp;Rigenerare icone</translation>
    </message>
    <message>
        <source>Preferences</source>
        <translation type="obsolete">Preferenze</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Synchronization</source>
        <translation>Sincronizzazione</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Update search index on startup</source>
        <translation>Aggiornamento indice di ricerca all&apos;avvio</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Display Options</source>
        <translation>Opzioni di visualizzazione</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Icon Size:</source>
        <translation>Icona dimensione:</translation>
    </message>
    <message>
        <location line="+44"/>
        <source>View Mode:</source>
        <translation>Modalità di visualizzazione:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Number of items
shown in search results:</source>
        <translation>Numero di oggetti
mostrati nei risultati di ricerca:</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>Library Sources</source>
        <translation>Biblioteca fonti</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Add...</source>
        <translation>Aggiungi…</translation>
    </message>
    <message>
        <source>Add ...</source>
        <translation type="obsolete">Aggiungi…</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Remove</source>
        <translation>Rimuovi</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Up</source>
        <translation>Su</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Down</source>
        <translation>Giù</translation>
    </message>
    <message>
        <location filename="../LibraryBrowserInit.js" line="-11"/>
        <source>&amp;Library Browser</source>
        <translation>&amp;Browser Librerie</translation>
    </message>
</context>
<context>
    <name>LibraryBrowserForm</name>
    <message>
        <location filename="../LibraryBrowser.ui" line="+28"/>
        <source>File System</source>
        <translation>File system</translation>
    </message>
    <message>
        <location line="+60"/>
        <source>Search</source>
        <translation>Cerca</translation>
    </message>
    <message>
        <location line="+197"/>
        <source>Favorites</source>
        <translation>Preferiti</translation>
    </message>
    <message>
        <source>Tags</source>
        <translation type="vanished">Tags</translation>
    </message>
    <message>
        <location line="-174"/>
        <source>Look for:</source>
        <translation>Cerca per:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Clear</source>
        <translation>Pulisci</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Find</source>
        <translation>Trova</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>Reset tag selection</source>
        <translation>Reimposta</translation>
    </message>
    <message>
        <source>about:blank</source>
        <translation type="vanished">about:blank</translation>
    </message>
    <message>
        <location line="+162"/>
        <source>Insert selected item into drawing</source>
        <translation>Inserire elemento selezionato nel disegno</translation>
    </message>
    <message>
        <location line="+27"/>
        <source>Update DB from file system</source>
        <translation>Aggiorna</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>0</source>
        <translation>0</translation>
    </message>
</context>
</TS>
